@@ -18,6 +18,8 @@ from .middleware import (
 )
 from .tracer import add_traces_to_fastapi
 
+GCP_LABELS_LOG_KEY = "logging.googleapis.com/labels"
+
 
 class InterceptHandler(logging.Handler):
     """
@@ -52,6 +54,7 @@ def stackdriver_sink(message, project):
     """
     record = message.record
     http_request = http_request_context.get()
+    labels: dict[str, str] = record.get("extra").get("labels", {})
     log_info = {
         "severity": record["level"].name,
         "message": record["message"],
@@ -61,7 +64,10 @@ def stackdriver_sink(message, project):
             "function": record["function"],
             "line": record["line"],
         },
-        "logging.googleapis.com/labels": {"x-request-id": correlation_id.get()},
+        GCP_LABELS_LOG_KEY: {
+            "x-request-id": correlation_id.get(),
+            **labels,
+        },
     }
     if http_request is not None:
         log_info["httpRequest"] = http_request
@@ -116,6 +122,6 @@ def setup_logging_fastapi_gcp(
     sink_for_project = partial(stackdriver_sink, project=GCP_PROJECT)
     logger.add(
         sink_for_project,
-        serialize=True,
+        # serialize=True,
         level=os.environ.get("LOGURU_LEVEL", "INFO"),
     )
